==> jc-1.4.0.tar.gz: jas/ByteOperand.h <==
// class jas.ByteOperand

// class file dependencies
// @dep_class 598766446e8745f2 jas_ByteOperand
// @dep_class 2c401db3553feabf jas_InsnOperand
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header jas_InsnOperand

#include "jas/InsnOperand.h"

#ifndef _JC_jas_ByteOperand_H_
#define _JC_jas_ByteOperand_H_

// Forward structure declarations
struct _jc_jas_ClassEnv$object;
struct _jc_jas_CodeAttr$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_ByteOperand$sub_refs	_jc_jas_ByteOperand$sub_refs;
typedef struct _jc_jas_ByteOperand$sub_nonrefs	_jc_jas_ByteOperand$sub_nonrefs;
typedef struct _jc_jas_ByteOperand$refs	_jc_jas_ByteOperand$refs;
typedef struct _jc_jas_ByteOperand$nonrefs	_jc_jas_ByteOperand$nonrefs;
typedef struct _jc_jas_ByteOperand$object	_jc_jas_ByteOperand$object;

typedef const struct _jc_jas_ByteOperand$vmethods	_jc_jas_ByteOperand$vmethods;
typedef const struct _jc_jas_ByteOperand$vtable	_jc_jas_ByteOperand$vtable;
typedef const struct _jc_jas_ByteOperand$vtype	_jc_jas_ByteOperand$vtype;

// Constructors
extern void _jc_jas_ByteOperand$method$_init$7f1776288300b98d(_jc_env *, struct _jc_jas_ByteOperand$object *, jint);

// Virtual methods
extern void _jc_jas_ByteOperand$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_ByteOperand$object *, struct _jc_jas_ClassEnv$object *);
extern jint _jc_jas_ByteOperand$method$size$ed865933e174f90a(_jc_env *, struct _jc_jas_ByteOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *);
extern void _jc_jas_ByteOperand$method$write$d61e8c36d8c1cacd(_jc_env *, struct _jc_jas_ByteOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_jas_ByteOperand$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_ByteOperand$method_info$size$ed865933e174f90a;
extern _jc_method _jc_jas_ByteOperand$method_info$write$d61e8c36d8c1cacd;

// Virtual methods structure
struct _jc_jas_ByteOperand$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_ByteOperand$object *, struct _jc_jas_ClassEnv$object *);
	jint	(*size$ed865933e174f90a)(_jc_env *, struct _jc_jas_ByteOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *);
	void	(*write$d61e8c36d8c1cacd)(_jc_env *, struct _jc_jas_ByteOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *);
};

// Vtable
struct _jc_jas_ByteOperand$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_InsnOperand$vmethods	jas_InsnOperand;
	_jc_jas_ByteOperand$vmethods	jas_ByteOperand;
};

// Vtype
struct _jc_jas_ByteOperand$vtype {
	_jc_type			type;
	_jc_jas_ByteOperand$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_ByteOperand$sub_refs {
};

// Reference instance fields (object)
struct _jc_jas_ByteOperand$refs {
    _jc_jas_ByteOperand$sub_refs	jas_ByteOperand;
    _jc_jas_InsnOperand$sub_refs	jas_InsnOperand;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_ByteOperand$sub_nonrefs {
	jint	val;
};

// Non-reference instance fields (object)
struct _jc_jas_ByteOperand$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_InsnOperand$sub_nonrefs	jas_InsnOperand;
    _jc_jas_ByteOperand$sub_nonrefs	jas_ByteOperand;
};

// Object instance structure
struct _jc_jas_ByteOperand$object {
	_jc_jas_ByteOperand$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_ByteOperand$vtype	*vtype;
	_jc_jas_ByteOperand$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_ByteOperand$vtype _jc_jas_ByteOperand$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_ByteOperand, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_ByteOperand$class_object;

#endif	/* _JC_jas_ByteOperand_H_ */

==> jc-1.4.6.tar.gz: jas/ByteOperand.h <==
// class jas.ByteOperand

// class file dependencies
// @dep_class 598766446e8745f2 jas_ByteOperand
// @dep_class 2c401db3553feabf jas_InsnOperand
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header jas_InsnOperand

#include "jas/InsnOperand.h"

#ifndef _JC_jas_ByteOperand_H_
#define _JC_jas_ByteOperand_H_

// Forward structure declarations
struct _jc_jas_ClassEnv$object;
struct _jc_jas_CodeAttr$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_ByteOperand$sub_refs	_jc_jas_ByteOperand$sub_refs;
typedef struct _jc_jas_ByteOperand$sub_nonrefs	_jc_jas_ByteOperand$sub_nonrefs;
typedef struct _jc_jas_ByteOperand$refs	_jc_jas_ByteOperand$refs;
typedef struct _jc_jas_ByteOperand$nonrefs	_jc_jas_ByteOperand$nonrefs;
typedef struct _jc_jas_ByteOperand$object	_jc_jas_ByteOperand$object;

typedef const struct _jc_jas_ByteOperand$vmethods	_jc_jas_ByteOperand$vmethods;
typedef const struct _jc_jas_ByteOperand$vtable	_jc_jas_ByteOperand$vtable;
typedef const struct _jc_jas_ByteOperand$vtype	_jc_jas_ByteOperand$vtype;

// Constructors
extern void _jc_jas_ByteOperand$method$_init$7f1776288300b98d(_jc_env *, struct _jc_jas_ByteOperand$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_jas_ByteOperand$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_ByteOperand$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
extern jint _jc_jas_ByteOperand$method$size$ed865933e174f90a(_jc_env *, struct _jc_jas_ByteOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *) _JC_JCNI_ATTR;
extern void _jc_jas_ByteOperand$method$write$d61e8c36d8c1cacd(_jc_env *, struct _jc_jas_ByteOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_jas_ByteOperand$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_ByteOperand$method_info$size$ed865933e174f90a;
extern _jc_method _jc_jas_ByteOperand$method_info$write$d61e8c36d8c1cacd;

// Virtual methods structure
struct _jc_jas_ByteOperand$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_ByteOperand$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
	jint	(*size$ed865933e174f90a)(_jc_env *, struct _jc_jas_ByteOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *) _JC_JCNI_ATTR;
	void	(*write$d61e8c36d8c1cacd)(_jc_env *, struct _jc_jas_ByteOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_jas_ByteOperand$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_InsnOperand$vmethods	jas_InsnOperand;
	_jc_jas_ByteOperand$vmethods	jas_ByteOperand;
};

// Vtype
struct _jc_jas_ByteOperand$vtype {
	_jc_type			type;
	_jc_jas_ByteOperand$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_ByteOperand$sub_refs {
};

// Reference instance fields (object)
struct _jc_jas_ByteOperand$refs {
    _jc_jas_ByteOperand$sub_refs	jas_ByteOperand;
    _jc_jas_InsnOperand$sub_refs	jas_InsnOperand;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_ByteOperand$sub_nonrefs {
	jint	val;
};

// Non-reference instance fields (object)
struct _jc_jas_ByteOperand$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_InsnOperand$sub_nonrefs	jas_InsnOperand;
    _jc_jas_ByteOperand$sub_nonrefs	jas_ByteOperand;
};

// Object instance structure
struct _jc_jas_ByteOperand$object {
	_jc_jas_ByteOperand$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_ByteOperand$vtype	*vtype;
	_jc_jas_ByteOperand$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_ByteOperand$vtype _jc_jas_ByteOperand$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_ByteOperand, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_ByteOperand$class_object;

#endif	/* _JC_jas_ByteOperand_H_ */
